==> humhub-1.6.3.tar.gz: humhub-1.6.3/protected/humhub/modules/admin/messages/de/settings.php <==
<?php
return array (
  '1 month' => '1 Monat',
  '1 week' => '1 Woche',
  '1 year' => '1 Jahr',
  '2 weeks' => '2 Wochen',
  '3 months' => '3 Monate',
  '6 months' => '6 Monate',
  '<strong>Confirm</strong> icon deletion' => 'Löschen des Icons <strong>bestätigen</strong>',
  '<strong>Confirm</strong> image deletion' => 'Löschen des Bildes <strong>bestätigen</strong>',
  'APC(u)' => 'APC(u)',
  'Add OEmbed provider' => 'OEmbed Anbieter hinzufügen',
  'Add new provider' => 'Neuen Anbieter hinzufügen',
  'Advanced Settings' => 'Erweiterte Einstellungen',
  'Allow Self-Signed Certificates?' => 'Selbst-signierte Zertifikate erlauben?',
  'Allowed file extensions' => 'Erlaubte Dateierweiterungen',
  'Alphabetical' => 'Alphabetisch',
  'Appearance Settings' => 'Anzeigeeinstellungen',
  'Auto format based on user language - Example: {example}' => 'Automatische Formatierung basierend auf der Benutzersprache - Beispiel: {example}',
  'Back to overview' => 'Zurück zur Übersicht',
  'Base URL' => 'Basis-URL',
  'Cache Backend' => 'Cache Backend',
  'Comma separated list. Leave empty to allow all.' => 'Komma-separierte Liste (CSV). Leer lassen, um alle zu erlauben.',
  'Could not send test email.' => 'Test-E-Mail konnte nicht versandt werden.',
  'Currently no provider active!' => 'Aktuell sind keine Anbieter eingerichtet!',
  'Currently there are {count} records in the database dating from {dating}.' => 'Beginnend mit dem {dating} enthält die Datenbank {count} Datensätze.',
  'Dashboard' => 'Übersicht',
  'Date input format' => 'Datumseingabeformat',
  'Default Expire Time (in seconds)' => 'Standardablaufzeit (in Sekunden)',
  'Default language' => 'Standardsprache',
  'Default pagination size (Entries per page)' => 'Standardseitengröße (Einträge pro Seite)',
  'Default stream content order' => 'Standardsortierung des Streams',
  'Delete' => 'Löschen',
  'Display Name (Format)' => 'Anzeigename (Format)',
  'Dropdown space order' => 'DropDown-Space-Sortierung',
  'E-Mail' => 'E-Mail',
  'E-Mail sender address' => 'E-Mail-Absenderadresse',
  'E-Mail sender name' => 'E-Mail-Absendername',
  'E.g. http://example.com/humhub' => 'z. B. http://example.com/humhub',
  'Edit OEmbed provider' => 'OEmbed Anbieter bearbeiten',
  'Enable user friendship system' => 'Aktivieren des Freundschaftssystems unter Benutzern',
  'Enabled' => 'Aktiviert',
  'Enabled OEmbed providers' => 'Aktivierte OEmbed Anbieter',
  'Encryption' => 'Verschlüsselung',
  'Endpoint Url' => 'Ziel-Url',
  'File' => 'Datei',
  'Firstname Lastname (e.g. John Doe)' => 'Vorname Nachname (z. B. Max Mustermann)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Festes Format (dd/mm/yyyy) - Beispiel: {example}',
  'Friendship' => 'Freundschaften',
  'General' => 'Allgemein',
  'General Settings' => 'Allgemeine Einstellungen',
  'HTML tracking code' => 'HTML Tracking Code',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Hier kannst du Registrierungseinstellungen und weitere Benutzereinstellungen deines sozialen Netzwerks konfigurieren.',
  'Here you can configure basic settings of your social network.' => 'Hier kannst du grundlegende Einstellungen deines sozialen Netzwerks konfigurieren.',
  'Hide file info (name, size) for images on wall' => 'Datei-Informationen (Name, Größe) für Bilder in der Übersicht ausblenden',
  'Horizontal scrolling images on a mobile device' => 'Bilder auf Mobilgeräten horizontal scrollen',
  'Icon upload' => 'Icon hochgeladen',
  'If not set, height will default to 200px.' => 'Ist dieser Wert nicht gesetzt, wird die Standard-Bildhöhe von 200px genutzt.',
  'If not set, width will default to 200px.' => 'Ist dieser Wert nicht gesetzt, wird die Standard-Bildbreite von 200px genutzt.',
  'Last visit' => 'Letzter Zugriff',
  'Logo upload' => 'Logo hochladen',
  'Mail Transport Type' => 'Mail Transport Typ',
  'Maximum allowed age for logs.' => 'Höchstalter für Protokolle',
  'Maximum preview image height (in pixels, optional)' => 'Maximalhöhe der Vorschaubilder (in Pixel, optional)',
  'Maximum preview image width (in pixels, optional)' => 'Maximalbreite der Vorschaubilder (in Pixel, optional)',
  'Maximum upload file size (in MB)' => 'Maximale Datei Upload Größe (in MB)',
  'Mobile appearance' => 'Mobile Version',
  'Name of the application' => 'Name der Anwendung',
  'No Proxy Hosts' => 'Keine Proxy-Hosts',
  'No caching' => 'Kein Caching',
  'None - shows dropdown in user registration.' => 'Keine - bei der Registrierung Drop-Down Auswahl zeigen',
  'Notification Settings' => 'Benachrichtungseinstellungen',
  'Old logs can significantly increase the size of your database while providing little information.' => 'Alte Protokolle können die Größe der Datenbank signifikant erhöhen, ohne einen großen Mehrwert an Informationen zu bieten.',
  'PHP APC(u) Extension missing - Type not available!' => 'PHP APC(u) Erweiterung nicht gefunden - Typ nicht verfügbar!',
  'PHP reported a maximum of {maxUploadSize} MB' => 'PHP meldet ein Maximum von {maxUploadSize} MB',
  'Password' => 'Passwort',
  'Port' => 'Port',
  'Port number' => 'Portnummer',
  'Prevent client caching of following scripts' => 'Zwischenspeichern der folgenden Skripte auf dem Client verhindern',
  'Redis' => 'Redis',
  'SMTP Options' => 'SMTP-Optionen',
  'Save' => 'Speichern',
  'Save & Flush Caches' => 'Speichern &amp; Cache leeren',
  'Save & Test' => 'Speichern &amp; Testen',
  'Saved' => 'Gespeichert',
  'Saved and flushed cache' => 'Gespeichert und Cache bereinigt',
  'Saved and sent test email to: {address}' => 'Gespeichert und Test E-Mail verschickt: {address}',
  'Server' => 'Server',
  'Server Timezone' => 'Server-Zeitzone',
  'Show introduction tour for new users' => 'Zeige Einführungstour für neue Benutzer',
  'Show user profile post form on dashboard' => 'Zeige Eingabe für Profil-Beiträge in der Übersicht',
  'Sort by creation date' => 'Nach Erstelldatum sortieren',
  'Sort by update date' => 'Nach Aktualisierungsdatum sortieren',
  'Test message' => 'Testnachricht',
  'Theme' => 'Thema',
  'These settings refer to advanced topics of your social network.' => 'Diese Einstellungen betreffen fortgeschrittene Themen deines sozialen Netzwerkes.',
  'These settings refer to the appearance of your social network.' => 'Diese Einstellungen beziehen sich auf die Darstellung deines Sozialen Netzwerks.',
  'Url Prefix' => 'Url Prefix',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'Url Prefix OHNE http:// oder https:// (z. B. youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Benutze %url% als Platzhalter für die URL. Als Format muss JSON zurückgegeben werden. (z. B. http://www.youtube.de/oembed?url=%url%&amp;format=json)',
  'Use X-Sendfile for File Downloads' => 'Benutze X-Sendfile für Datei Downloads',
  'Use the default swipe to show sidebar on a mobile device' => 'Standard-Swipe verwenden, um die Seitenleiste auf einem mobilen Gerät anzuzeigen',
  'User' => 'Benutzer',
  'User Settings' => 'Benutzereinstellungen',
  'Username' => 'Benutzername',
  'Username (e.g. john)' => 'Benutzername (z. B. max)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Du kannst HTML Code für Statistiken hinzufügen, der zu allen generierten Seiten hinzugefügt wird.',
  'You\'re using no icon at the moment. Upload your logo now.' => 'Zurzeit verwendest du kein Symbol. Jetzt dein Logo hochladen.',
  'You\'re using no logo at the moment. Upload your logo now.' => 'Du benutzt momentan kein eigenes Logo. Lade dein eigenes Logo hoch.',
  'never' => 'Nie',
);

==> humhub-1.8.1.tar.gz: humhub-1.8.1/protected/humhub/modules/admin/messages/de/settings.php <==
<?php
return array (
  '1 month' => '1 Monat',
  '1 week' => '1 Woche',
  '1 year' => '1 Jahr',
  '2 weeks' => '2 Wochen',
  '3 months' => '3 Monate',
  '6 months' => '6 Monate',
  '<strong>Confirm</strong> icon deletion' => 'Löschen des Icons <strong>bestätigen</strong>',
  '<strong>Confirm</strong> image deletion' => 'Löschen des Bildes <strong>bestätigen</strong>',
  '<strong>Maintenance</strong> Mode' => '<strong>Wartungsmodus</strong>',
  '<strong>Warning:</strong> All users will be immediately logged out, except admins.' => '<strong>Warnung:</strong> Alle Benutzer werden automatisch abgemeldet, außer Administratoren.',
  'APC(u)' => 'APC(u)',
  'Activate' => 'Aktivieren',
  'Activate maintenance mode and disable access to the platform for non-admin users?<br><br>' => 'Wartungsmodus aktivieren und alle Benutzer außer Administratoren automatisch abmelden?',
  'Add OEmbed provider' => 'OEmbed Anbieter hinzufügen',
  'Add custom info text for maintenance mode. Displayed on the login page.' => 'Benutzerdefinierten Informationstext für den Wartungsmodus hinzufügen, wird auf der Anmeldeseite angezeigt.',
  'Add new provider' => 'Neuen Anbieter hinzufügen',
  'Advanced Settings' => 'Erweiterte Einstellungen',
  'Allow Self-Signed Certificates?' => 'Selbst-signierte Zertifikate erlauben?',
  'Allowed file extensions' => 'Erlaubte Dateierweiterungen',
  'Alphabetical' => 'Alphabetisch',
  'Appearance Settings' => 'Anzeigeeinstellungen',
  'Auto format based on user language - Example: {example}' => 'Automatische Formatierung basierend auf der Benutzersprache - Beispiel: {example}',
  'Back to overview' => 'Zurück zur Übersicht',
  'Base URL' => 'Basis-URL',
  'Cache Backend' => 'Cache Backend',
  'Comma separated list. Leave empty to allow all.' => 'Komma-separierte Liste (CSV). Leer lassen, um alle zu erlauben.',
  'Could not send test email.' => 'Test-E-Mail konnte nicht versandt werden.',
  'Currently no provider active!' => 'Aktuell sind keine Anbieter eingerichtet!',
  'Currently there are {count} records in the database dating from {dating}.' => 'Beginnend mit dem {dating} enthält die Datenbank {count} Datensätze.',
  'Dashboard' => 'Übersicht',
  'Date input format' => 'Datumseingabeformat',
  'Deactivate' => 'Deaktivieren',
  'Deactivate maintenance mode and enable all users to access the platform again?' => 'Wartungsmodus deaktivieren und allen Benutzern den Zugriff auf die Plattform wieder ermöglichen?',
  'Default Expire Time (in seconds)' => 'Standardablaufzeit (in Sekunden)',
  'Default language' => 'Standardsprache',
  'Default pagination size (Entries per page)' => 'Standardseitengröße (Einträge pro Seite)',
  'Default stream content order' => 'Standardsortierung des Streams',
  'Delete' => 'Löschen',
  'Display Name (Format)' => 'Anzeigename (Format)',
  'Dropdown space order' => 'DropDown-Space-Sortierung',
  'E-Mail' => 'E-Mail',
  'E-Mail sender address' => 'E-Mail-Absenderadresse',
  'E-Mail sender name' => 'E-Mail-Absendername',
  'E.g. http://example.com/humhub' => 'z. B. http://example.com/humhub',
  'Edit OEmbed provider' => 'OEmbed Anbieter bearbeiten',
  'Enable maintenance mode' => 'Wartungsmodus aktivieren',
  'Enable user friendship system' => 'Aktivieren des Freundschaftssystems unter Benutzern',
  'Enabled' => 'Aktiviert',
  'Enabled OEmbed providers' => 'Aktivierte OEmbed Anbieter',
  'Encryption' => 'Verschlüsselung',
  'Endpoint Url' => 'Ziel-Url',
  'Exclude media files from stream attachment list' => 'Mediendateien nicht zusätzlich als Anhänge von Beiträgen aufführen',
  'File' => 'Datei',
  'Firstname Lastname (e.g. John Doe)' => 'Vorname Nachname (z. B. Max Mustermann)',
  'Fixed format (dd/mm/yyyy) - Example: {example}' => 'Festes Format (dd/mm/yyyy) - Beispiel: {example}',
  'Friendship' => 'Freundschaften',
  'General' => 'Allgemein',
  'General Settings' => 'Allgemeine Einstellungen',
  'HTML tracking code' => 'HTML Tracking Code',
  'Here you can configurate the registration behaviour and additinal user settings of your social network.' => 'Hier kannst du Registrierungseinstellungen und weitere Benutzereinstellungen deines sozialen Netzwerks konfigurieren.',
  'Here you can configure basic settings of your social network.' => 'Hier kannst du grundlegende Einstellungen deines sozialen Netzwerks konfigurieren.',
  'Horizontal scrolling images on a mobile device' => 'Bilder auf Mobilgeräten horizontal scrollen',
  'Icon upload' => 'Icon hochgeladen',
  'Last visit' => 'Letzter Zugriff',
  'Logo upload' => 'Logo hochladen',
  'Mail Transport Type' => 'Mail Transport Typ',
  'Maintenance mode' => 'Wartungsmodus',
  'Maximum allowed age for logs.' => 'Höchstalter für Protokolle',
  'Maximum upload file size (in MB)' => 'Maximale Datei Upload Größe (in MB)',
  'Mobile appearance' => 'Mobile Version',
  'Name of the application' => 'Name der Anwendung',
  'No Proxy Hosts' => 'Keine Proxy-Hosts',
  'No caching' => 'Kein Caching',
  'Notification Settings' => 'Benachrichtigungen',
  'Old logs can significantly increase the size of your database while providing little information.' => 'Alte Protokolle können die Größe der Datenbank signifikant erhöhen, ohne einen großen Mehrwert an Informationen zu bieten.',
  'PHP APC(u) Extension missing - Type not available!' => 'PHP APC(u) Erweiterung nicht gefunden - Typ nicht verfügbar!',
  'PHP reported a maximum of {maxUploadSize} MB' => 'PHP meldet ein Maximum von {maxUploadSize} MB',
  'Password' => 'Passwort',
  'Port' => 'Port',
  'Port number' => 'Portnummer',
  'Prevent client caching of following scripts' => 'Zwischenspeichern der folgenden Skripte auf dem Client verhindern',
  'Redis' => 'Redis',
  'Reported database time: {dateTime}' => 'Gemeldete Datenbankzeit: {dateTime}',
  'SMTP Options' => 'SMTP-Optionen',
  'Save' => 'Speichern',
  'Save & Flush Caches' => 'Speichern &amp; Cache leeren',
  'Save & Test' => 'Speichern &amp; Testen',
  'Saved' => 'Gespeichert',
  'Saved and flushed cache' => 'Gespeichert und Cache bereinigt',
  'Saved and sent test email to: {address}' => 'Gespeichert und Test E-Mail verschickt: {address}',
  'Server' => 'Server',
  'Server Timezone' => 'Server-Zeitzone',
  'Show introduction tour for new users' => 'Zeige Einführungstour für neue Benutzer',
  'Show user profile post form on dashboard' => 'Zeige Eingabe für Profil-Beiträge in der Übersicht',
  'Sort by creation date' => 'Nach Erstelldatum sortieren',
  'Sort by update date' => 'Nach Aktualisierungsdatum sortieren',
  'Test message' => 'Testnachricht',
  'Theme' => 'Thema',
  'These settings refer to advanced topics of your social network.' => 'Diese Einstellungen betreffen fortgeschrittene Themen deines sozialen Netzwerkes.',
  'These settings refer to the appearance of your social network.' => 'Diese Einstellungen beziehen sich auf die Darstellung deines Sozialen Netzwerks.',
  'Url Prefix' => 'Url Prefix',
  'Url Prefix without http:// or https:// (e.g. youtube.com)' => 'Url Prefix OHNE http:// oder https:// (z. B. youtube.com)',
  'Use %url% as placeholder for URL. Format needs to be JSON. (e.g. http://www.youtube.com/oembed?url=%url%&format=json)' => 'Benutze %url% als Platzhalter für die URL. Als Format muss JSON zurückgegeben werden. (z. B. http://www.youtube.de/oembed?url=%url%&amp;format=json)',
  'Use X-Sendfile for File Downloads' => 'Benutze X-Sendfile für Datei Downloads',
  'Use the default swipe to show sidebar on a mobile device' => 'Standard-Swipe verwenden, um die Seitenleiste auf einem mobilen Gerät anzuzeigen',
  'User' => 'Benutzer',
  'User Settings' => 'Benutzereinstellungen',
  'Username' => 'Benutzername',
  'Username (e.g. john)' => 'Benutzername (z. B. max)',
  'You can add a statistic code snippet (HTML) - which will be added to all rendered pages.' => 'Du kannst HTML Code für Statistiken hinzufügen, der zu allen generierten Seiten hinzugefügt wird.',
  'You\'re using no icon at the moment. Upload your logo now.' => 'Zurzeit verwendest du kein Symbol. Jetzt dein Logo hochladen.',
  'You\'re using no logo at the moment. Upload your logo now.' => 'Du benutzt momentan kein eigenes Logo. Lade dein eigenes Logo hoch.',
  'never' => 'Nie',
);
